country

# XMLRésuméLibrary: User Guide

copyright | Element Reference | county

## Name

country — A country name

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None

## Description

The `country` element marks the name of a country.

### Parents

`country` may be contained in these elements: `address`, `location`

### Attributes

`id`

  A string used to uniquely identify a country. The country may then be referred to by this identifier.

## Examples

    <address>
      <city>Portland</city>
      <state>Oregon</state>
      <country>USA</country>
    </address>

    <address>
      <street>2621 Green Loop</street>
      <street>Southam</street>
      <city>Wiggleworm</city>
      <postalCode>S521 2GR</postalCode>
      <country>UK</country>
    </address>

copyright | Element Reference | county